package Qt::Gui::QStyleOptionProgressBarV2;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QStyleOptionProgressBarV2
# file     : QtGui/qstyleoption.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QStyleOptionProgressBar/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QStyleOptionProgressBarV2

=head1 PUBLIC METHODS

=over

=item   QStyleOptionProgressBarV2()

=item   QStyleOptionProgressBarV2(const QStyleOptionProgressBar & other)

=item   QStyleOptionProgressBarV2(const QStyleOptionProgressBarV2 & other)

=item  QStyleOptionProgressBarV2 & operator=(const QStyleOptionProgressBar & other)


=back

=head1 ENUM VALUES

=over

=item Type

=item Version


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
